@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_flx.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -664,6 +664,16 @@ class TrackMeHandlerSplkFlxTrackingRead_v2(trackme_rest_handler.RESTHandler):
                     else:
                         mtime = "N/A"
 
+                    # Get score, default to 100 if not present (for backward compatibility)
+                    score = kvrecord.get("score")
+                    if score is None:
+                        score = 100
+                    else:
+                        try:
+                            score = int(score)
+                        except (TypeError, ValueError):
+                            score = 100
+                    
                     return_records.append(
                         {
                             "_key": kvrecord.get("_key"),
@@ -674,6 +684,7 @@ class TrackMeHandlerSplkFlxTrackingRead_v2(trackme_rest_handler.RESTHandler):
                             "condition_true": kvrecord.get("condition_true"),
                             "mtime": mtime,
                             "comment": kvrecord.get("comment"),
+                            "score": score,
                         }
                     )
             except:
